# Laakhay

Brand wrapper for Laakhay Open Source Wings.

## Usage

First, install `laakhay` and the sub-package `laakhay-quantlab`.

```bash
pip install laakhay laakhay-quantlab
```

Then you can access quantlab modules, for example:

```python
from laakhay.quantlab import hello

hello()
```